CREATE TABLE IF NOT EXISTS "backup" (
  "id" integer PRIMARY KEY AUTOINCREMENT,
  "type" text,
  "name" text,
  "target" text,
  "root" text,
  "path" text,
  "size" text,
  "created" text
);

CREATE TABLE IF NOT EXISTS "crontab" (
  "id" text NOT NULL,
  "type" text,
  "name" text,
  "period" text,
  "week" integer,
  "day" integer,
  "hour" integer,
  "minute" integer,
  "shell" text,
  "url" text,
  "backup" text,
  "backup_num" integer,
  "runtime" text,
  "status" integer DEFAULT 0,
  "updated" text,
  "cron" text,
  "created" TEXT
);

CREATE TABLE IF NOT EXISTS "database" (
  "id" integer NOT NULL,
  "name" text,
  "user" text,
  "pass" text,
  "accept" text,
  "backup" integer DEFAULT 0,
  "updated" text,
  "created" text,
  "type" text,
  "charset" text,
  "remark" text,
  PRIMARY KEY ("id")
);

CREATE TABLE IF NOT EXISTS "download" (
  "id" integer NOT NULL PRIMARY KEY AUTOINCREMENT,
  "url" text,
  "path" text,
  "status" text,
  "created" text,
  "updated" text
);

CREATE TABLE IF NOT EXISTS "firewall" (
  "id" integer NOT NULL DEFAULT 0 PRIMARY KEY AUTOINCREMENT,
  "value" text,
  "type" text DEFAULT port,
  "remark" text,
  "created" text,
  "protocol" text
);

CREATE TABLE IF NOT EXISTS "logs" (
  "id" integer PRIMARY KEY AUTOINCREMENT,
  "target" text,
  "type" text,
  "message" text,
  "created" text
);

CREATE TABLE IF NOT EXISTS "pem" (
  "subject" text NOT NULL,
  "not_after" text,
  "not_before" text,
  "issuer" text,
  "dns" text,
  "key" text,
  "cert" text,
  "created" text,
  "updated" text,
  PRIMARY KEY ("subject")
);

CREATE TABLE IF NOT EXISTS "proxy" (
  "name" text NOT NULL,
  "subject" text,
  "host" text,
  "url" text,
  "dir" text,
  "filter" text,
  "filter_open" integer DEFAULT 0,
  "cache_enabled" text,
  "cache_time" real,
  "created" text,
  "updated" text,
  PRIMARY KEY ("name")
);

CREATE TABLE IF NOT EXISTS "redirect" (
  "name" text NOT NULL,
  "subject" text,
  "type" text,
  "url" text,
  "code" integer DEFAULT 301,
  "path" text,
  "param" text,
  "created" text,
  "updated" text,
  PRIMARY KEY ("name")
);

CREATE TABLE IF NOT EXISTS "sftp" (
  "id" integer NOT NULL PRIMARY KEY AUTOINCREMENT,
  "name" text,
  "pass" text,
  "root" text,
  "enabled" text,
  "remark" text,
  "created" text,
  "updated" text
);

CREATE TABLE IF NOT EXISTS "site" (
  "id" integer NOT NULL,
  "domain" text,
  "name" text,
  "type" text,
  "remark" text,
  "created" text,
  "updated" text,
  "sort" integer DEFAULT 0,
  "expired" text,
  "root" text,
  "sftp_name" text,
  "db_name" text,
  "main" text,
  "root_dir" text,
  "config" text,
  "key" text,
  "cert" text,
  "enabled" integer DEFAULT 0,
  "version" text,
  PRIMARY KEY ("id")
);

CREATE TABLE IF NOT EXISTS "soft" (
  "name" text NOT NULL,
  "title" text,
  "type" text,
  "remark" text,
  "os" text,
  "price" integer DEFAULT 0,
  "sort" integer DEFAULT 0,
  "author" text,
  "home" text,
  "icon" text,
  "install_checks" text,
  "uninstall_checks" text,
  "version_coexist" integer,
  "versions" text,
  "updated" text,
  "expired" text,
  "index_display" integer DEFAULT 0,
  "shell" text,
  "config_checks" text,
  "shell_checks" text,
  "process_checks" text,
  "mutex" text,
  "depend" text,
  PRIMARY KEY ("name")
);

CREATE TABLE IF NOT EXISTS "tasking" (
  "id" integer NOT NULL PRIMARY KEY AUTOINCREMENT,
  "type" text,
  "name" text,
  "status" integer DEFAULT 0,
  "created" text,
  "started" integer DEFAULT 0,
  "ended" integer DEFAULT 0,
  "content" text,
  "pid" integer DEFAULT 0
);

CREATE TABLE IF NOT EXISTS "user" (
  "id" integer PRIMARY KEY AUTOINCREMENT,
  "username" text,
  "password" text,
  "phone" text,
  "email" text,
  "role" text DEFAULT super,
  "login_ip" text,
  "login_time" text,
  "created" text,
  "updated" text,
  "avatar" text
);

INSERT INTO "user"("id", "username", "password", "phone", "email", "role", "login_ip", "login_time", "created", "updated", "avatar") VALUES (1, 'treepanel', '25f9e794323b453885f5181f1b624d0b', '15260209869', '15260209869@qq.com', 'super', '192.168.88.102', '2019/08/13 00:35:48', NULL, '2019-08-13 00:35:48', '/public/avatar/treepanel.png');