<VirtualHost *:{{.Port}}>
    #ServerAdmin webmaster@example.com

    DocumentRoot "{{.Root}}"
    ServerName {{.Main}}
    ServerAlias {{.Domain}}

    #errorDocument 404 /404.html

    {{if .AccessLog}}
    #响应日志
    CustomLog "{{.Logs}}/{{.Main}}.log" combined
    {{end}}

    {{if .ErrorLog}}
    #错误日志
    ErrorLog "{{.Logs}}/{{.Main}}.error.log"
    {{end}}

    {{if .Rewrite}}
    #引用伪静态规则
    IncludeOptional {{.Server}}/vhost/apache/rewrite/{{.Main}}*.conf
    {{end}}

    {{if .Redirect}}
    #引用重定向规则
    IncludeOptional {{.Server}}/vhost/apache/redirect/{{.Main}}/*.conf
    {{end}}

    {{if .Proxy}}
    #引用反向代理规则
    IncludeOptional {{.Server}}/vhost/apache/proxy/{{.Main}}/*.conf
    {{end}}

    {{if .Linking.Enabled}}
    #防盗链配置
    RewriteEngine on
    RewriteCond %{HTTP_REFERER} !^$ [NC]
    RewriteCond %{HTTP_REFERER} !{{.Linking.Domain}} [NC]
    RewriteRule .({{.Linking.Ext}}) /404.html [R=404,NC,L]
    {{end}}

    {{if .Ssl.Enabled}}
    #HTTP_TO_HTTPS_START
    <IfModule mod_rewrite.c>
        RewriteEngine on
        RewriteCond %{SERVER_PORT} !^443$
        RewriteRule (.*) https://%{SERVER_NAME}$1 [L,R=301]
    </IfModule>
    #HTTP_TO_HTTPS_END
    {{end}}

    {{if .FileDir}}
    #禁止访问的文件
    <Files ~ ({{.FileDir}})$>
       Order allow,deny
       Deny from all
    </Files>
    {{end}}

    {{if eq .Type "php"}}
    {{if .Version}}
    #PHP引用配置
    {{if eq .Logs "C:/www/wwwlogs"}}
    Include conf/enable-php-{{.Version}}.conf
    {{else}}
    <FilesMatch \.php$>
        SetHandler "proxy:unix:/tmp/php-cgi-{{.Version}}.sock|fcgi://localhost"
    </FilesMatch>
    {{end}}
    {{end}}
    {{end}}

    <Directory "{{.Root}}">
        SetOutputFilter DEFLATE
        Options FollowSymLinks
        AllowOverride All
        Require all granted
        DirectoryIndex {{.Index}}
    </Directory>
</VirtualHost>

{{if .Ssl.Enabled}}
<VirtualHost *:443>
    #ServerAdmin webmaster@example.com
    DocumentRoot "{{.Root}}"
    ServerName SSL.{{.Main}}
    ServerAlias {{.Domain}}
    #errorDocument 404 /404.html
    {{if .AccessLog}}
    CustomLog "{{.Logs}}/{{.Main}}.log" combined
    {{end}}
    {{if .ErrorLog}}
    ErrorLog "{{.Logs}}/{{.Main}}.error.log"
    {{end}}

    {{if .Rewrite}}
    #引用伪静态规则
    IncludeOptional {{.Server}}/vhost/apache/rewrite/{{.Main}}*.conf
    {{end}}

    {{if .Redirect}}
    #引用重定向规则
    IncludeOptional {{.Server}}/vhost/apache/redirect/{{.Main}}/*.conf
    {{end}}

    {{if .Proxy}}
    #引用反向代理规则
    IncludeOptional {{.Server}}/vhost/apache/proxy/{{.Main}}/*.conf
    {{end}}

    {{if .Linking.Enabled}}
    #防盗链配置
    RewriteEngine on
    RewriteCond %{HTTP_REFERER} !^$ [NC]
    RewriteCond %{HTTP_REFERER} !{{.Linking.Domain}} [NC]
    RewriteRule .({{.Linking.Ext}}) /404.html [R=404,NC,L]
    {{end}}

    {{if .Ssl.Enabled}}
    #SSL相关配置
    SSLEngine On
    SSLCertificateFile {{.Ssl.Cert}}
    SSLCertificateKeyFile {{.Ssl.Key}}
    SSLCipherSuite EECDH+AESGCM:EDH+AESGCM:AES256+EECDH:AES256+EDH
    SSLProtocol All -SSLv2 -SSLv3
    SSLHonorCipherOrder On
    {{end}}

    {{if eq .Type "php"}}
    {{if .Version}}
    #PHP引用配置
    {{if eq .Logs "C:/www/wwwlogs"}}
    Include conf/enable-php-{{.Version}}.conf
    {{else}}
    <FilesMatch \.php$>
       SetHandler "proxy:unix:/tmp/php-cgi-{{.Version}}.sock|fcgi://localhost"
    </FilesMatch>
    {{end}}
    {{end}}
    {{end}}

    {{if .FileDir}}
    #禁止访问的文件
    <Files ~ ({{.FileDir}})$>
       Order allow,deny
       Deny from all
    </Files>
    {{end}}

    <Directory "{{.Root}}">
        SetOutputFilter DEFLATE
        Options FollowSymLinks
        AllowOverride All
        Require all granted
        DirectoryIndex {{.Index}}
    </Directory>
</VirtualHost>
{{end}}