server
{
    listen {{.Port}};
    {{if .Ssl.Enabled}}
    #SSL-START
	listen 443 ssl http2;
	#SSL-END
    {{end}}
    server_name {{.Domain}};
    index {{.Index}};
    root {{.Root}};


    {{if .Ssl.Enabled}}
    #SSL-START SSL相关配置
    #error_page 404/404.html;
    #HTTP_TO_HTTPS_START
    if ($server_port !~ 443){
        rewrite ^(/.*)$ https://$host$1 permanent;
    }
    #HTTP_TO_HTTPS_END
    ssl_certificate {{.Ssl.Cert}};
    ssl_certificate_key {{.Ssl.Key}};
    ssl_protocols {{.Ssl.Pool}};
    ssl_ciphers ECDHE-RSA-AES128-GCM-SHA256:HIGH:!aNULL:!MD5:!RC4:!DHE;
    ssl_prefer_server_ciphers on;
    ssl_session_cache shared:SSL:10m;
    ssl_session_timeout 10m;
    error_page  497  https://$host$request_uri;
    #SSL-END
    {{end}}

    {{if .Redirect}}
    #REDIRECT-START 引用重定向规则
    include {{.Server}}/vhost/nginx/redirect/{{.Main}}/*.conf;
    #REDIRECT-END
    {{end}}

    #ERROR-PAGE-START 错误页配置
    #error_page 404 /404.html;
    #error_page 502 /502.html;
    #ERROR-PAGE-END

    {{if .Proxy}}
    #PROXY-START 引用反向代理规则
    #include {{.Server}}/vhost/nginx/proxy/{{.Main}}/*.conf;
    #PROXY-END
    {{end}}

    {{if .Limit.Enabled}}
    #LIMIT-START 流量限制配置
    limit_conn perserver {{.Limit.Perserver}};
    limit_conn perip {{.Limit.Perip}};
    limit_rate {{.Limit.Rate}}k;
    #LIMIT-END
    {{end}}

    {{if eq .Type "php"}}
    {{if .Version}}
    #PHP-INFO-START  PHP引用配置
    include enable-php-{{.Version}}.conf;
    #PHP-INFO-END
    {{end}}
    {{end}}

    {{if .Linking.Enabled}}
    #LOCATION-START 防盗链配置
    location ~ .*\.({{.Linking.Ext}})$
    {
        expires {{.Linking.Expires}}d;
        access_log /dev/null;
        valid_referers none blocked {{.Linking.Domain}};
        if ($invalid_referer){
           return 404;
        }
    }
    #LOCATION-END
    {{end}}

    {{if .Rewrite}}
    #REWRITE-START URL重写规则引用
    include {{.Server}}/vhost/nginx/rewrite/{{.Main}}.conf;
    #REWRITE-END
    {{end}}

    {{if .FileDir}}
    #LOCATION-START 禁止访问的文件
    location ~ ^/({{.FileDir}})
    {
        return 404;
    }
    #LOCATION-END
    {{end}}

    #LOCATION-START SSL证书验证目录相关设置
    location ~ \.well-known{
        allow all;
    }
    #LOCATION-END

    {{if .Pic.Enabled}}
    #LOCATION-START 图片缓存设置
    location ~ .*\.({{.Pic.Ext}})$
    {
        expires {{.Pic.Expires}}d;
        error_log off;
        access_log off;
    }
    #LOCATION-END
    {{end}}

    {{if .Asset.Enabled}}
    #LOCATION-START 资源缓存设置
    location ~ .*\.({{.Asset.Ext}})?$
    {
        expires {{.Asset.Expires}}h;
        error_log off;
        access_log off;
    }
    #LOCATION-END
    {{end}}

    {{if .AccessLog}}
    #响应日志
    access_log {{.Logs}}/{{.Main}}.log;
    {{end}}

    {{if .ErrorLog}}
    #错误日志
    error_log {{.Logs}}/{{.Main}}.error.log;
    {{end}}
}